# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.setup_tools_api import SetupToolsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestSetupToolsApi(unittest.TestCase):
    """SetupToolsApi unit test stubs"""

    def setUp(self):
        self.api = SetupToolsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_spreadsheet(self):
        """Test case for get_spreadsheet

        Gets the template spreadsheet for the given job type  # noqa: E501
        """
        pass

    def test_run_setup_tool_job(self):
        """Test case for run_setup_tool_job

        Enqueues a job of the given type to be run  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
