# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DashboardCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'template_id': 'int',
        'corporation_id': 'str',
        'location_id': 'str',
        'time_range': 'WidgetTimeRangeValues',
        'power_bi_report_url': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'description': 'Description',
        'template_id': 'TemplateId',
        'corporation_id': 'CorporationId',
        'location_id': 'LocationId',
        'time_range': 'TimeRange',
        'power_bi_report_url': 'PowerBiReportUrl'
    }

    def __init__(self, name=None, description=None, template_id=None, corporation_id=None, location_id=None, time_range=None, power_bi_report_url=None):  # noqa: E501
        """DashboardCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._template_id = None
        self._corporation_id = None
        self._location_id = None
        self._time_range = None
        self._power_bi_report_url = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        self.template_id = template_id
        self.corporation_id = corporation_id
        if location_id is not None:
            self.location_id = location_id
        if time_range is not None:
            self.time_range = time_range
        if power_bi_report_url is not None:
            self.power_bi_report_url = power_bi_report_url

    @property
    def name(self):
        """Gets the name of this DashboardCreateRequest.  # noqa: E501


        :return: The name of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DashboardCreateRequest.


        :param name: The name of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this DashboardCreateRequest.  # noqa: E501


        :return: The description of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DashboardCreateRequest.


        :param description: The description of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def template_id(self):
        """Gets the template_id of this DashboardCreateRequest.  # noqa: E501


        :return: The template_id of this DashboardCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this DashboardCreateRequest.


        :param template_id: The template_id of this DashboardCreateRequest.  # noqa: E501
        :type: int
        """
        if template_id is None:
            raise ValueError("Invalid value for `template_id`, must not be `None`")  # noqa: E501

        self._template_id = template_id

    @property
    def corporation_id(self):
        """Gets the corporation_id of this DashboardCreateRequest.  # noqa: E501


        :return: The corporation_id of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._corporation_id

    @corporation_id.setter
    def corporation_id(self, corporation_id):
        """Sets the corporation_id of this DashboardCreateRequest.


        :param corporation_id: The corporation_id of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """
        if corporation_id is None:
            raise ValueError("Invalid value for `corporation_id`, must not be `None`")  # noqa: E501

        self._corporation_id = corporation_id

    @property
    def location_id(self):
        """Gets the location_id of this DashboardCreateRequest.  # noqa: E501


        :return: The location_id of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this DashboardCreateRequest.


        :param location_id: The location_id of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def time_range(self):
        """Gets the time_range of this DashboardCreateRequest.  # noqa: E501


        :return: The time_range of this DashboardCreateRequest.  # noqa: E501
        :rtype: WidgetTimeRangeValues
        """
        return self._time_range

    @time_range.setter
    def time_range(self, time_range):
        """Sets the time_range of this DashboardCreateRequest.


        :param time_range: The time_range of this DashboardCreateRequest.  # noqa: E501
        :type: WidgetTimeRangeValues
        """

        self._time_range = time_range

    @property
    def power_bi_report_url(self):
        """Gets the power_bi_report_url of this DashboardCreateRequest.  # noqa: E501


        :return: The power_bi_report_url of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._power_bi_report_url

    @power_bi_report_url.setter
    def power_bi_report_url(self, power_bi_report_url):
        """Sets the power_bi_report_url of this DashboardCreateRequest.


        :param power_bi_report_url: The power_bi_report_url of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """

        self._power_bi_report_url = power_bi_report_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
