# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RepeaterModelV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'serial_number': 'str',
        'radio_mac_address': 'str',
        'location_id': 'str',
        'location_name': 'str',
        'corporation_id': 'str',
        'corporation_name': 'str',
        'last_status_update': 'datetime',
        'active': 'bool',
        'type': 'ReceiverLocationTypeCodes'
    }

    attribute_map = {
        'id': 'Id',
        'serial_number': 'SerialNumber',
        'radio_mac_address': 'RadioMacAddress',
        'location_id': 'LocationId',
        'location_name': 'LocationName',
        'corporation_id': 'CorporationId',
        'corporation_name': 'CorporationName',
        'last_status_update': 'LastStatusUpdate',
        'active': 'Active',
        'type': 'Type'
    }

    def __init__(self, id=None, serial_number=None, radio_mac_address=None, location_id=None, location_name=None, corporation_id=None, corporation_name=None, last_status_update=None, active=None, type=None):  # noqa: E501
        """RepeaterModelV3 - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._serial_number = None
        self._radio_mac_address = None
        self._location_id = None
        self._location_name = None
        self._corporation_id = None
        self._corporation_name = None
        self._last_status_update = None
        self._active = None
        self._type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.serial_number = serial_number
        if radio_mac_address is not None:
            self.radio_mac_address = radio_mac_address
        if location_id is not None:
            self.location_id = location_id
        if location_name is not None:
            self.location_name = location_name
        if corporation_id is not None:
            self.corporation_id = corporation_id
        if corporation_name is not None:
            self.corporation_name = corporation_name
        if last_status_update is not None:
            self.last_status_update = last_status_update
        if active is not None:
            self.active = active
        if type is not None:
            self.type = type

    @property
    def id(self):
        """Gets the id of this RepeaterModelV3.  # noqa: E501


        :return: The id of this RepeaterModelV3.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RepeaterModelV3.


        :param id: The id of this RepeaterModelV3.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def serial_number(self):
        """Gets the serial_number of this RepeaterModelV3.  # noqa: E501


        :return: The serial_number of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this RepeaterModelV3.


        :param serial_number: The serial_number of this RepeaterModelV3.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def radio_mac_address(self):
        """Gets the radio_mac_address of this RepeaterModelV3.  # noqa: E501


        :return: The radio_mac_address of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._radio_mac_address

    @radio_mac_address.setter
    def radio_mac_address(self, radio_mac_address):
        """Sets the radio_mac_address of this RepeaterModelV3.


        :param radio_mac_address: The radio_mac_address of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._radio_mac_address = radio_mac_address

    @property
    def location_id(self):
        """Gets the location_id of this RepeaterModelV3.  # noqa: E501


        :return: The location_id of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this RepeaterModelV3.


        :param location_id: The location_id of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def location_name(self):
        """Gets the location_name of this RepeaterModelV3.  # noqa: E501


        :return: The location_name of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._location_name

    @location_name.setter
    def location_name(self, location_name):
        """Sets the location_name of this RepeaterModelV3.


        :param location_name: The location_name of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._location_name = location_name

    @property
    def corporation_id(self):
        """Gets the corporation_id of this RepeaterModelV3.  # noqa: E501


        :return: The corporation_id of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._corporation_id

    @corporation_id.setter
    def corporation_id(self, corporation_id):
        """Sets the corporation_id of this RepeaterModelV3.


        :param corporation_id: The corporation_id of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._corporation_id = corporation_id

    @property
    def corporation_name(self):
        """Gets the corporation_name of this RepeaterModelV3.  # noqa: E501


        :return: The corporation_name of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._corporation_name

    @corporation_name.setter
    def corporation_name(self, corporation_name):
        """Sets the corporation_name of this RepeaterModelV3.


        :param corporation_name: The corporation_name of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._corporation_name = corporation_name

    @property
    def last_status_update(self):
        """Gets the last_status_update of this RepeaterModelV3.  # noqa: E501


        :return: The last_status_update of this RepeaterModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._last_status_update

    @last_status_update.setter
    def last_status_update(self, last_status_update):
        """Sets the last_status_update of this RepeaterModelV3.


        :param last_status_update: The last_status_update of this RepeaterModelV3.  # noqa: E501
        :type: datetime
        """

        self._last_status_update = last_status_update

    @property
    def active(self):
        """Gets the active of this RepeaterModelV3.  # noqa: E501


        :return: The active of this RepeaterModelV3.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this RepeaterModelV3.


        :param active: The active of this RepeaterModelV3.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def type(self):
        """Gets the type of this RepeaterModelV3.  # noqa: E501


        :return: The type of this RepeaterModelV3.  # noqa: E501
        :rtype: ReceiverLocationTypeCodes
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RepeaterModelV3.


        :param type: The type of this RepeaterModelV3.  # noqa: E501
        :type: ReceiverLocationTypeCodes
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RepeaterModelV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RepeaterModelV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
