# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.activities_api import ActivitiesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestActivitiesApi(unittest.TestCase):
    """ActivitiesApi unit test stubs"""

    def setUp(self):
        self.api = ActivitiesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_activity(self):
        """Test case for create_activity

        Creates an Activity  # noqa: E501
        """
        pass

    def test_delete_activity(self):
        """Test case for delete_activity

        Deletes an activity  # noqa: E501
        """
        pass

    def test_get_activities(self):
        """Test case for get_activities

        Gets Activities  # noqa: E501
        """
        pass

    def test_get_activity(self):
        """Test case for get_activity

        Gets an Activity  # noqa: E501
        """
        pass

    def test_get_activity_categories(self):
        """Test case for get_activity_categories

        Gets activity categories  # noqa: E501
        """
        pass

    def test_get_activity_codes(self):
        """Test case for get_activity_codes

        Gets activity codes for category type  # noqa: E501
        """
        pass

    def test_update_activity(self):
        """Test case for update_activity

        Updates an Activity  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
