# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'user_first_name': 'str',
        'user_last_name': 'str',
        'user_email': 'str'
    }

    attribute_map = {
        'user_id': 'UserId',
        'user_first_name': 'UserFirstName',
        'user_last_name': 'UserLastName',
        'user_email': 'UserEmail'
    }

    def __init__(self, user_id=None, user_first_name=None, user_last_name=None, user_email=None):  # noqa: E501
        """UserChild - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._user_first_name = None
        self._user_last_name = None
        self._user_email = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        if user_first_name is not None:
            self.user_first_name = user_first_name
        if user_last_name is not None:
            self.user_last_name = user_last_name
        if user_email is not None:
            self.user_email = user_email

    @property
    def user_id(self):
        """Gets the user_id of this UserChild.  # noqa: E501


        :return: The user_id of this UserChild.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserChild.


        :param user_id: The user_id of this UserChild.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_first_name(self):
        """Gets the user_first_name of this UserChild.  # noqa: E501


        :return: The user_first_name of this UserChild.  # noqa: E501
        :rtype: str
        """
        return self._user_first_name

    @user_first_name.setter
    def user_first_name(self, user_first_name):
        """Sets the user_first_name of this UserChild.


        :param user_first_name: The user_first_name of this UserChild.  # noqa: E501
        :type: str
        """

        self._user_first_name = user_first_name

    @property
    def user_last_name(self):
        """Gets the user_last_name of this UserChild.  # noqa: E501


        :return: The user_last_name of this UserChild.  # noqa: E501
        :rtype: str
        """
        return self._user_last_name

    @user_last_name.setter
    def user_last_name(self, user_last_name):
        """Sets the user_last_name of this UserChild.


        :param user_last_name: The user_last_name of this UserChild.  # noqa: E501
        :type: str
        """

        self._user_last_name = user_last_name

    @property
    def user_email(self):
        """Gets the user_email of this UserChild.  # noqa: E501


        :return: The user_email of this UserChild.  # noqa: E501
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email):
        """Sets the user_email of this UserChild.


        :param user_email: The user_email of this UserChild.  # noqa: E501
        :type: str
        """

        self._user_email = user_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
