# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DashboardPermissionsUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_sentry_managed': 'bool',
        'is_visible_to_customers': 'bool'
    }

    attribute_map = {
        'is_sentry_managed': 'IsSentryManaged',
        'is_visible_to_customers': 'IsVisibleToCustomers'
    }

    def __init__(self, is_sentry_managed=None, is_visible_to_customers=None):  # noqa: E501
        """DashboardPermissionsUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._is_sentry_managed = None
        self._is_visible_to_customers = None
        self.discriminator = None
        self.is_sentry_managed = is_sentry_managed
        self.is_visible_to_customers = is_visible_to_customers

    @property
    def is_sentry_managed(self):
        """Gets the is_sentry_managed of this DashboardPermissionsUpdateRequest.  # noqa: E501


        :return: The is_sentry_managed of this DashboardPermissionsUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_sentry_managed

    @is_sentry_managed.setter
    def is_sentry_managed(self, is_sentry_managed):
        """Sets the is_sentry_managed of this DashboardPermissionsUpdateRequest.


        :param is_sentry_managed: The is_sentry_managed of this DashboardPermissionsUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_sentry_managed is None:
            raise ValueError("Invalid value for `is_sentry_managed`, must not be `None`")  # noqa: E501

        self._is_sentry_managed = is_sentry_managed

    @property
    def is_visible_to_customers(self):
        """Gets the is_visible_to_customers of this DashboardPermissionsUpdateRequest.  # noqa: E501


        :return: The is_visible_to_customers of this DashboardPermissionsUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible_to_customers

    @is_visible_to_customers.setter
    def is_visible_to_customers(self, is_visible_to_customers):
        """Sets the is_visible_to_customers of this DashboardPermissionsUpdateRequest.


        :param is_visible_to_customers: The is_visible_to_customers of this DashboardPermissionsUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_visible_to_customers is None:
            raise ValueError("Invalid value for `is_visible_to_customers`, must not be `None`")  # noqa: E501

        self._is_visible_to_customers = is_visible_to_customers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardPermissionsUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardPermissionsUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
