# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IdentityProviderCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'username_identifiers': 'list[str]',
        'corporation_id': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'username_identifiers': 'UsernameIdentifiers',
        'corporation_id': 'CorporationId'
    }

    def __init__(self, name=None, username_identifiers=None, corporation_id=None):  # noqa: E501
        """IdentityProviderCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._username_identifiers = None
        self._corporation_id = None
        self.discriminator = None
        self.name = name
        if username_identifiers is not None:
            self.username_identifiers = username_identifiers
        self.corporation_id = corporation_id

    @property
    def name(self):
        """Gets the name of this IdentityProviderCreateRequest.  # noqa: E501


        :return: The name of this IdentityProviderCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IdentityProviderCreateRequest.


        :param name: The name of this IdentityProviderCreateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def username_identifiers(self):
        """Gets the username_identifiers of this IdentityProviderCreateRequest.  # noqa: E501


        :return: The username_identifiers of this IdentityProviderCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._username_identifiers

    @username_identifiers.setter
    def username_identifiers(self, username_identifiers):
        """Sets the username_identifiers of this IdentityProviderCreateRequest.


        :param username_identifiers: The username_identifiers of this IdentityProviderCreateRequest.  # noqa: E501
        :type: list[str]
        """

        self._username_identifiers = username_identifiers

    @property
    def corporation_id(self):
        """Gets the corporation_id of this IdentityProviderCreateRequest.  # noqa: E501


        :return: The corporation_id of this IdentityProviderCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._corporation_id

    @corporation_id.setter
    def corporation_id(self, corporation_id):
        """Sets the corporation_id of this IdentityProviderCreateRequest.


        :param corporation_id: The corporation_id of this IdentityProviderCreateRequest.  # noqa: E501
        :type: str
        """
        if corporation_id is None:
            raise ValueError("Invalid value for `corporation_id`, must not be `None`")  # noqa: E501

        self._corporation_id = corporation_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IdentityProviderCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IdentityProviderCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
